@@ -1,7 +1,7 @@
 /* BayesX - Software for Bayesian Inference in
 Structured Additive Regression Models.
-Copyright (C) 2011  Christiane Belitz, Andreas Brezger,
-Thomas Kneib, Stefan Lang, Nikolaus Umlauf
+Copyright (C) 2019 Christiane Belitz, Andreas Brezger,
+Nadja Klein, Thomas Kneib, Stefan Lang, Nikolaus Umlauf
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -29,9 +29,6 @@ void estimaterun(dagobject & d)
   bool error = false;
 
   MCMCoptions mopt(
-  #if defined(JAVA_OUTPUT_WINDOW)
-  d.adminb_p,
-  #endif
   d.iterations.getvalue(),d.burnin.getvalue(),d.step.getvalue(),d.logout);
   mopt.set_nrout(d.iterationsprint.getvalue());
 
@@ -519,15 +516,9 @@ void dagobject::create(void)
 
 
 dagobject::dagobject(
-  #if defined(JAVA_OUTPUT_WINDOW)
-  administrator_basic * adb,
-  #endif
   const ST::string & n,ofstream * lo,istream * i,ST::string p,
             vector<statobject*> * st)
          : statobject(
-         #if defined(JAVA_OUTPUT_WINDOW)
-         adb,
-         #endif
          n,"dag",lo,i,p)
   {
 
