@@ -1,7 +1,7 @@
 /* BayesX - Software for Bayesian Inference in
 Structured Additive Regression Models.
-Copyright (C) 2011  Christiane Belitz, Andreas Brezger,
-Thomas Kneib, Stefan Lang, Nikolaus Umlauf
+Copyright (C) 2019 Christiane Belitz, Andreas Brezger,
+Nadja Klein, Thomas Kneib, Stefan Lang, Nikolaus Umlauf
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -75,14 +75,8 @@ void FULLCOND_tvariance::outresults(void)
   FULLCOND::outresults();
 
   optionsp->out("  Results are stored in file " + pathresult + "\n");
-  #if defined(JAVA_OUTPUT_WINDOW)
-  optionsp->out("  Results may be visualized using method 'plotnonp'\n");
-  optionsp->out("  Type for example: objectname.plotnonp " +
-                   ST::inttostring(fcnumber) + " , median levels=none\n");
-  #else
   optionsp->out("  Results may be visualized using the R function");
   optionsp->out(" 'plotnonp'\n");
-  #endif
   optionsp->out("\n");
 
   unsigned i;
