@@ -1,7 +1,7 @@
 /* BayesX - Software for Bayesian Inference in
 Structured Additive Regression Models.
-Copyright (C) 2011  Christiane Belitz, Andreas Brezger,
-Thomas Kneib, Stefan Lang, Nikolaus Umlauf
+Copyright (C) 2019 Christiane Belitz, Andreas Brezger,
+Nadja Klein, Thomas Kneib, Stefan Lang, Nikolaus Umlauf
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -28,10 +28,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include<vector>
 #include"clstring.h"
 
-#if defined(JAVA_OUTPUT_WINDOW)
-#include"adminparse_basic.h"
-#endif
-
 using std::cout;
 
 namespace MCMC
@@ -55,10 +51,6 @@ class __EXPORT_TYPE GENERAL_OPTIONS
 
   public:
 
-  #if defined(JAVA_OUTPUT_WINDOW)
-  administrator_basic * adminb_p;
-  #endif
-
   unsigned iterations;            // Number of iterations
   unsigned burnin;                // Number of burnin iterations
   unsigned step;                  // Thinning parameter
@@ -96,8 +88,7 @@ class __EXPORT_TYPE GENERAL_OPTIONS
 
   bool IWLSlineff;
   bool forceIWLS;
-
-
+  bool highspeedon;
 
   // DEFAULT CONSTRUCTOR
   // Defines:
@@ -128,12 +119,10 @@ class __EXPORT_TYPE GENERAL_OPTIONS
   // copula = cop
 
   GENERAL_OPTIONS(
-  #if defined(JAVA_OUTPUT_WINDOW)
-                  administrator_basic * abp,
-  #endif
                   const unsigned & it,const unsigned & bu,const unsigned & st,
                   const bool & sa,const bool & cop, const unsigned & rot,
                   const bool & samsel, const double & samselval, const bool & fiwls,
+                  const bool & hso,
                   ostream * lo=&cout,const double & l1=95,
                   const double & l2=80);
 
