@@ -49,13 +49,13 @@ using randnumbers::rand_inv_gaussian;
 using randnumbers::invPhi2;
 
 /*
-1. workingweights ndern sich, weights ungleich 1
+1. workingweights aendern sich, weights ungleich 1
 
-2. workingweights ndern sich, weights gleich eins
+2. workingweights aendern sich, weights gleich eins
 
-3. workingweights ndern sich nicht und sind konstant
+3. workingweights aendern sich nicht und sind konstant
 
-4. workingweights ndern sich nicht und sind eins
+4. workingweights aendern sich nicht und sind eins
 */
 
 enum weighttype{wweightschange_weightsneqone,wweightschange_weightsone,
@@ -806,6 +806,8 @@ class __EXPORT_TYPE DISTR_quantreg : public DISTR_gaussian
   double num;
   double sigma02;
 
+  datamatrix weightoriginal;
+
   public:
 
    // DEFAULT CONSTRUCTOR
